@@ -32,10 +32,9 @@ static const char description[] =
 
 int main(int argc, char **argv)
 {
-    KAboutData about("muon-installer", "muon-installer", ki18n("Muon Software Center"), version, ki18n(description),
+    KAboutData about("muoninstaller", "muon-installer", ki18n("Muon Software Center"), version, ki18n(description),
                      KAboutData::License_GPL, ki18n("©2010-2012 Jonathan Thomas"), KLocalizedString(), 0);
     about.addAuthor(ki18n("Jonathan Thomas"), KLocalizedString(), "echidnaman@kubuntu.org");
-    about.setProgramIconName("applications-other");
     about.setProductName("muon/installer");
 
     KCmdLineArgs::init(argc, argv, &about);
@@ -50,9 +49,10 @@ int main(int argc, char **argv)
     }
 
     KUniqueApplication app;
+    app.setWindowIcon(QIcon::fromTheme("applications-other"));
     // Translations
-    KGlobal::locale()->insertCatalog("app-install-data");
-    KGlobal::locale()->insertCatalog("libmuon");
+    //     KGlobal::locale()->insertCatalog("app-install-data"); //FIXME: Port to kf5
+//     KGlobal::locale()->insertCatalog("libmuon"); //FIXME: Port to kf5
     // Needed for KIcon compatibility w/ application icons from app-install-data
     KGlobal::dirs()->addResourceDir("appicon", "/usr/share/app-install/icons/");
     app.disableSessionManagement();
