@@ -682,7 +682,7 @@ void ApplicationBackend::listBugsFinished()
     mProcess->deleteLater();
     if (!output.isEmpty()) {
         QMessageBox::StandardButton reply;
-        reply = QMessageBox::question(mainWindow(), QString("Bugs found"), output ,QMessageBox::Yes|QMessageBox::No);
+        reply = QMessageBox::question(mainWindow(), i18n("Bugs found"), output ,QMessageBox::Yes|QMessageBox::No);
         if (reply == QMessageBox::No) {
             ok = false;
         }
@@ -699,14 +699,14 @@ void ApplicationBackend::listBugsFinished()
 void ApplicationBackend::aptListBugs(QStringList packageName)
 {
     QStringList arguments;
-    QString program = QStandardPaths::findExecutable(QString("apt-listbugs"));
+    QString program = QStandardPaths::findExecutable(QStringLiteral("apt-listbugs"));
     if (program.isEmpty()) {
         emit transactionOk();
         return;
     }
     KProcess *proc = new KProcess;
     proc->setOutputChannelMode(KProcess::OnlyStdoutChannel);
-    proc->setShellCommand(program.append(QString(" list ")).append(packageName.join(" , ")));
+    proc->setShellCommand(program.append(QStringLiteral(" list ")).append(packageName.join(" , ")));
     connect(proc, SIGNAL(finished(int)), this, SLOT(listBugsFinished()));
     proc->start();
 }
