@@ -71,7 +71,7 @@ void ApplicationNotifier::init()
 
 void ApplicationNotifier::distUpgradeEvent()
 {
-    QString checkerFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "muonapplicationnotifier/releasechecker");
+    QString checkerFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "libmuon/applicationsbackend/releasechecker");
     if (checkerFile.isEmpty()) {
         qWarning() << "Couldn't find the releasechecker" << checkerFile << QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation);
         return;
