@@ -479,12 +479,14 @@ void ApplicationUpdates::calculateUpdates()
         for(QApt::Package* it : pkgList) {
             AbstractResource* res = m_appBackend->resourceByPackageName(it->name());
             if(!res) //If we couldn't find it by its name, try with
-                res = m_appBackend->resourceByPackageName(QString("%1:%2").arg(it->name()).arg(it->architecture()));
+                res = m_appBackend->resourceByPackageName(QStringLiteral("%1:%2").arg(it->name()).arg(it->architecture()));
 
-            if(res)
-                m_toUpdate += res;
-            else
+            if(res) {
+                if (res->state() == Application::Upgradeable)
+                    m_toUpdate += res;
+            } else {
                 qWarning() << "Couldn't find the package:" << it->name();
+            }
             Q_ASSERT(res);
         }
     }
