@@ -57,6 +57,9 @@ PackageKitBackend::PackageKitBackend(QObject* parent)
     t->setInterval(60 * 60 * 1000);
     t->setSingleShot(false);
     t->start();
+
+    connect(PackageKit::Daemon::global(), &PackageKit::Daemon::updatesChanged, this, &PackageKitBackend::fetchUpdates);
+    connect(PackageKit::Daemon::global(), &PackageKit::Daemon::isRunningChanged, this, &PackageKitBackend::checkDaemonRunning);
 }
 
 PackageKitBackend::~PackageKitBackend()
@@ -99,6 +102,13 @@ void PackageKitBackend::reloadPackageList()
     connect(t, SIGNAL(errorCode(PackageKit::Transaction::Error,QString)), SLOT(transactionError(PackageKit::Transaction::Error,QString)));
     acquireFetching(true);
 
+    fetchUpdates();
+}
+
+void PackageKitBackend::fetchUpdates()
+{
+    m_updatesPackageId.clear();
+
     PackageKit::Transaction * tUpdates = PackageKit::Daemon::getUpdates();
     connect(tUpdates, SIGNAL(finished(PackageKit::Transaction::Exit,uint)), this, SLOT(getUpdatesFinished(PackageKit::Transaction::Exit,uint)));
     connect(tUpdates, SIGNAL(package(PackageKit::Transaction::Info, QString, QString)), SLOT(addPackageToUpdate(PackageKit::Transaction::Info,QString,QString)));
@@ -106,6 +116,7 @@ void PackageKitBackend::reloadPackageList()
     acquireFetching(true);
 }
 
+
 void PackageKitBackend::addPackage(PackageKit::Transaction::Info info, const QString &packageId, const QString &summary)
 {
     QString packageName = PackageKit::Daemon::packageName(packageId);
@@ -274,10 +285,16 @@ QString PackageKitBackend::upgradeablePackageId(PackageKitResource* res) const
         if (PackageKit::Daemon::packageName(pkgid) == name)
             return pkgid;
     }
-    Q_ASSERT(false && "requesting upgradeable pkg id for non-upgradeable package");
     return QString();
 }
 
+void PackageKitBackend::checkDaemonRunning()
+{
+    if (!PackageKit::Daemon::isRunning()) {
+        qWarning() << "PackageKit stopped running!";
+    }
+}
+
 AbstractBackendUpdater* PackageKitBackend::backendUpdater() const
 {
     return m_updater;
